@@ -12,7 +12,8 @@
 ## to safely call these methods.
 
 make_Weka_classifier <-
-function(name, class = NULL, handlers = list(), init = NULL)
+    function(name, class = NULL, handlers = list(), init = NULL,
+             package = NULL)
 {
     
     ## Return a function interfacing the Weka classification learner
@@ -27,7 +28,8 @@ function(name, class = NULL, handlers = list(), init = NULL)
     classes <- c(class, "Weka_classifier")
     kind <- "R_Weka_classifier_interface"
     name <- as_JNI_name(name)
-    meta <- make_R_Weka_interface_metadata(name, kind, classes, init)
+    meta <- make_R_Weka_interface_metadata(name, kind, classes, init,
+                                           package)
     Weka_interfaces[[Java_class_base_name(name)]] <- meta
 
     ## Provide a default data handler.
@@ -46,7 +48,7 @@ function(name, class = NULL, handlers = list(), init = NULL)
         mf <- eval(mf, parent.frame())
 	
         .structure(c(RWeka_build_classifier(mf, control, name, handlers,
-                                            options, init),
+                                            options, init, package),
                      list(call = mc, handlers = handlers,
                           levels = levels(mf[[1L]]),
                           terms = attr(mf, "terms"))),
@@ -56,9 +58,12 @@ function(name, class = NULL, handlers = list(), init = NULL)
 }
 
 RWeka_build_classifier <-
-function(mf, control, name, handlers, options, init)
+function(mf, control, name, handlers, options, init, package)
 {
-    if(is.function(init)) init()
+    if(is.function(init))
+        init()
+    else if(!is.null(package))
+        WPM(".check-installed-and-load", package)
 
     out <- list()
 
@@ -73,7 +78,7 @@ function(mf, control, name, handlers, options, init)
     instances <- read_model_frame_into_Weka(mf)
 
     ## Build the classifier.
-    classifier <- Weka_object_for_name(name)
+    classifier <- Weka_object_for_name(name, package)
     control <- as.character(.compose_and_funcall(handlers$control,
                                                  control))
     if(length(control))
